# PyKolada
A Python package for interacting with Kolada's statistical API.

## Installation
The package can be installed from PyPI using pip:
```bash
pip install kolada
```
OR
```bash
pip install pykolada
```

The two packages are identical, and depend on the same code. The only difference is the name of the package.

